Matchbox is a tool to make record matching iterative, collaborative and measurable.

It allows you to connect datasets using your organisation's best possible intelligence, and makes querying connected datasets quicker than a left join.

The Matchbox package will be deployed to PyPI in the near future.

You can use Matchbox to:

* Retrieve data that others have linked or deduplicated using Matchbox
* Build matching pipelines to link or deduplicate data